summaryrefslogtreecommitdiffstats
path: root/src/tools/qstring.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-01-26 23:32:43 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-01-26 23:32:43 -0600
commitea318d1431c89e647598c510c4245c6571aa5f46 (patch)
tree996d29b80c30d453dda86d1a23162d441628f169 /src/tools/qstring.cpp
parentaaf89d4b48f69c9293feb187db26362e550b5561 (diff)
downloadtqt3-ea318d1431c89e647598c510c4245c6571aa5f46.tar.gz
tqt3-ea318d1431c89e647598c510c4245c6571aa5f46.zip
Update to latest tqt3 automated conversion
Diffstat (limited to 'src/tools/qstring.cpp')
-rw-r--r--src/tools/qstring.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/tools/qstring.cpp b/src/tools/qstring.cpp
index ae582e34c..f4946a01a 100644
--- a/src/tools/qstring.cpp
+++ b/src/tools/qstring.cpp
@@ -44,13 +44,13 @@
#undef QT_NO_CAST_ASCII
#endif
-#include "qstring.h"
-#include "qregexp.h"
-#include "qdatastream.h"
+#include "ntqstring.h"
+#include "ntqregexp.h"
+#include "ntqdatastream.h"
#ifndef QT_NO_TEXTCODEC
-#include "qtextcodec.h"
+#include "ntqtextcodec.h"
#endif
-#include "qlocale.h"
+#include "ntqlocale.h"
#include "qlocale_p.h"
#include "qunicodetables_p.h"
@@ -66,7 +66,7 @@
#include "qt_windows.h"
#endif
#if !defined( QT_NO_COMPONENT ) && !defined( QT_LITE_COMPONENT )
-#include "qcleanuphandler.h"
+#include "ntqcleanuphandler.h"
#endif
#ifndef LLONG_MAX
@@ -148,7 +148,7 @@ static char qToLower(char c)
}
/*!
- \class TQCharRef qstring.h
+ \class TQCharRef ntqstring.h
\reentrant
\brief The TQCharRef class is a helper class for TQString.
@@ -167,7 +167,7 @@ static char qToLower(char c)
*/
/*!
- \class TQChar qstring.h
+ \class TQChar ntqstring.h
\reentrant
\brief The TQChar class provides a lightweight Unicode character.
@@ -1092,7 +1092,7 @@ void TQString::compose()
// These macros are used for efficient allocation of TQChar strings.
// IMPORTANT! If you change these, make sure you also change the
// "delete unicode" statement in ~TQStringData() in qstring.h correspondingly!
#define QT_ALLOC_QCHAR_VEC( N ) (TQChar*) new char[ sizeof(TQChar)*( N ) ]
#define QT_DELETE_QCHAR_VEC( P ) delete[] ((char*)( P ))
@@ -1229,7 +1229,7 @@ char* TQString::unicodeToLatin1(const TQChar *uc, uint l)
*****************************************************************************/
/*!
- \class TQString qstring.h
+ \class TQString ntqstring.h
\reentrant
\brief The TQString class provides an abstraction of Unicode text
@@ -1278,7 +1278,7 @@ char* TQString::unicodeToLatin1(const TQChar *uc, uint l)
and join a list of strings into a single string with an optional
separator using TQStringList::join(). You can obtain a list of
strings from a string list that contain a particular substring or
- that match a particular \link qregexp.html regex\endlink using
+ that match a particular \link ntqregexp.html regex\endlink using
TQStringList::grep().
<b>Note for C programmers</b>
@@ -4442,7 +4442,7 @@ TQString &TQString::replace( const TQString & before, const TQString & after )
// s == "ba"
\endcode
- For regexps containing \link qregexp.html#capturing-text capturing
+ For regexps containing \link ntqregexp.html#capturing-text capturing
parentheses \endlink, occurrences of <b>\\1</b>, <b>\\2</b>, ...,
in \a after are replaced with \a{rx}.cap(1), cap(2), ...
@@ -6914,7 +6914,7 @@ TQDataStream &operator>>( TQDataStream &s, TQString &str )
*****************************************************************************/
/*!
- \class TQConstString qstring.h
+ \class TQConstString ntqstring.h
\reentrant
\ingroup text
\brief The TQConstString class provides string objects using constant Unicode data.
@@ -1092,7 +1092,7 @@ void TQString::compose()
// These macros are used for efficient allocation of TQChar strings.
// IMPORTANT! If you change these, make sure you also change the
-// "delete unicode" statement in ~TQStringData() in qstring.h correspondingly!
+// "delete unicode" statement in ~TQStringData() in ntqstring.h correspondingly!
#define QT_ALLOC_QCHAR_VEC( N ) (TQChar*) new char[ sizeof(TQChar)*( N ) ]
#define QT_DELETE_QCHAR_VEC( P ) delete[] ((char*)( P ))